# Word Cloud of @mentionedusers in tweets by YOU

## Introduction

First we're extracting out all **@mentionedusers** from tweets by this user & generate word cloud from it, where emphasized words denote frequent mentioning.

## Example

Below is a demonstration of word cloud, generated from my tweets.

![wordCloudOfMentionedUsersInTweetsByAnjan_Roy](../plots/wordCloudOfMentionedUsersInTweetsByAnjan_Roy.png)
